import blender_plots.blender_utils
import blender_plots.plots_base
import blender_plots.scatter
import blender_plots.surface
import blender_plots.arrows

from blender_plots.scatter import Scatter
from blender_plots.surface import Surface
from blender_plots.arrows import Arrows
